from setuptools import setup

setup(name='distributions_DtoE',
      version='0.1',
      description='Gaussian distributions',
      packages=['distributions_DtoE'],
      author = 'ReneeJia',
      author_email = 'rj368@cornell.edu',
      zip_safe=False)
